Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(803)

Unified Diff: webrtc/base/timeutils.h

Issue 1923213002: Rename rtc::Time64 --> rtc::TimeMillis. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Clarify TODO comment. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | webrtc/base/timeutils.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/base/timeutils.h
diff --git a/webrtc/base/timeutils.h b/webrtc/base/timeutils.h
index 4af0d9538f058f9d969f954cd9a7fb5620463fd7..52edbbf3245fd302ec7846890565a098ca7e9cc8 100644
--- a/webrtc/base/timeutils.h
+++ b/webrtc/base/timeutils.h
@@ -35,11 +35,11 @@ typedef uint32_t TimeStamp;
uint32_t Time32();
// Returns the current time in milliseconds in 64 bits.
-int64_t Time64();
+int64_t TimeMillis();
// Returns the current time in milliseconds.
// TODO(honghaiz): Returns Time64 once majority of the webrtc code migrates to
// 64-bit timestamp.
inline uint32_t Time() {
return Time32();
}
@@ -35,11 +35,11 @@ typedef uint32_t TimeStamp;
// Returns the current time in milliseconds.
-// TODO(honghaiz): Returns Time64 once majority of the webrtc code migrates to
-// 64-bit timestamp.
+// TODO(honghaiz): Change to return TimeMillis() once majority of the webrtc
+// code migrates to 64-bit timestamp.
inline uint32_t Time() {
return Time32();
« no previous file with comments | « no previous file | webrtc/base/timeutils.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698